Coverage for Bio.Sequencing: 100%

# Coverage for Bio.Sequencing : 100%

## 1 statements 1 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 | # This code is part of the Biopython distribution and governed by its # license. Please see the LICENSE file that should have been included # as part of this package. # """Code to deal with various programs for sequencing and assembly. This code deals with programs such as Phred, Phrap and Consed -- which provide utilities for calling bases from sequencing reads, and assembling sequences into contigs. """